@@ -1,11 +1,11 @@
 
 class IntError(Exception):
     def __init__(self, value):
-        super().__init__("\"{}\" was not a interger".format(value))
+        super().__init__("\"{}\" was not an integer".format(value))
 
 class ConnectionError(Exception):
     def __init__(self):
-        super().__init__("Connetion Timeout, failed to connect to website. Most likely the site is offline, try again later")
+        super().__init__("Connetion Timeout, failed to connect to website. Most likely because the site is offline. Try again later")
 
 class ServerError(Exception):
     def __init__(self, value):
@@ -13,7 +13,7 @@ class ServerError(Exception):
 
 class Unauthorized(Exception):
     def __init__(self):
-        super().__init__("You did not pass in a vailid API key".format())
+        super().__init__("You did not pass in a valid API key".format())
 
 class Forbidden(Exception):
     def __init__(self):
@@ -21,5 +21,5 @@ class Forbidden(Exception):
 
 class BotNotFound(Exception):
     def __init__(self, bot_id):
-        super().__init__("The bot with \"{}\" was not found".format(bot_id))
+        super().__init__("The bot with the ID \"{}\" was not found".format(bot_id))
 
